pub struct Database {
pub field_names: Vec<String>,
pub notice: String,
pub precision: u8,
pub table_type: TableType,
pub version: u8,
/* private fields */
}Expand description
Zone database.
Fields
field_names: Vec<String>Names of all the fields in the database.
notice: StringDatabase notice text (e.g. for licensing information).
precision: u8Precision of the data.
table_type: TableTypeType of data (country or timezone).
version: u8Encoding version.
Implementations
Sourceimpl Database
impl Database
Sourcepub fn simple_lookup(&self, location: Location) -> Option<String>
pub fn simple_lookup(&self, location: Location) -> Option<String>
Get a simple description of a location.
For a country database this will be the country name, for the timezone database it will be the timezone ID.
Sourcepub fn lookup(&self, location: Location) -> ZoneLookup
pub fn lookup(&self, location: Location) -> ZoneLookup
Perform a full database lookup for a location.